@@ -248,7 +248,7 @@ SPLINE_EVAL_F77( double const* theta, double const* zn,
 /*-----------------------------------------------------------------------*/
 void
 READ_SPLINE_DATA_F77( char const filename[], int const* io_unit, 
-                      double* rms_amplitude, long ln )
+                      double* rms_amplitude, mst_fortran_charlen_t ln )
 {
   int     io_dir    = 0;
   int     iostat    = 0;
@@ -647,7 +647,7 @@ cread_spline_data( char const filename[] )
 /*-----------------------------------------------------------------------*/
 void
 WRITE_SPLINE_DATA_F77( char const filename[], int const* io_unit, 
-                       int const* io_format, long ln )
+                       int const* io_format, mst_fortran_charlen_t ln )
 {
   int     io_dir = 1;
   int     iostat = 0;
@@ -934,7 +934,7 @@ write_fits_spline_data( char const filename[] )
       ttype[0] = "Z";
       ttype[1] = "THETA";
 
-      sprintf( tform[0], "%dD", s_scoef.qz );
+      sprintf( tform[0], "%ldD", s_scoef.qz );
       sprintf( tform[1], "%ldD", s_scoef.num_theta_knots );
 
       if ( fits_create_tbl( fptr, BINARY_TBL, (LONGLONG) 0, 2, ttype, tform, NULL, "SPLKNOTS", &status ) )  {
@@ -963,9 +963,9 @@ write_fits_spline_data( char const filename[] )
       ttype[1] = "COEFDIFZ";
       ttype[2] = "COEFDIFT";
 
-      sprintf( tform[0], "%dD", s_scoef.qz );
-      sprintf( tform[1], "%dD", s_scoef.qz-1 );
-      sprintf( tform[2], "%dD", s_scoef.qz );
+      sprintf( tform[0], "%ldD", s_scoef.qz );
+      sprintf( tform[1], "%ldD", s_scoef.qz-1 );
+      sprintf( tform[2], "%ldD", s_scoef.qz );
 
       if ( fits_create_tbl( fptr, BINARY_TBL, (LONGLONG) 0, 3,
 			    ttype, tform, NULL, "SPLCOEFF", &status ) ) {
